ExtremePointSet

Struct ExtremePointSet 

pub struct ExtremePointSet { /* private fields */ }
Extreme Point Set manager.

Implementations

Source

impl ExtremePointSet

pub fn new(boundary: &Boundary3D, margin: f64, spacing: f64) -> Self

Creates a new extreme point set for a container.

pub fn len(&self) -> usize

Returns the number of extreme points.

pub fn is_empty(&self) -> bool

Returns true if empty.

pub fn placed_count(&self) -> usize

Returns the number of placed boxes.

pub fn total_volume(&self) -> f64

Returns total placed volume.

pub fn total_mass(&self) -> f64

Returns total placed mass.

pub fn placed_boxes(&self) -> &[PlacedBox]

Returns the placed boxes.

pub fn try_place( &mut self, geom: &Geometry3D, instance: usize, orientation: usize, ) -> Option<Vector3<f64>>

Tries to place a box, returns the placement position if successful.